@@ -79,6 +79,9 @@ class ACEye():
         self.all_files(parsed_json)
         parsed_json = json.dumps(self.bgp_rr(), indent=4, sort_keys=True)
         self.all_files(parsed_json)
+        parsed_json = json.dumps(self.interface_policies(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+
 
     def make_directories(self):
         api_list = ['Tenant',
@@ -95,6 +98,7 @@ class ACEye():
                     'Fabric Nodes',
                     'Fault Summary',
                     'Filters',
+                    'Interface Policies',
                     'IP Addresses',
                     'License Entitlements',
                     'L2Outs',
@@ -351,6 +355,13 @@ class ACEye():
         response_dict  = response.json()
         return(response_dict)
 
+    def interface_policies(self):
+        self.url = f"{ self.aci }/api/node/class/infraPortS.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Interface Policies Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
     def json_file(self, parsed_json):
         if "Tenant" in self.url:
             with open('Tenant/JSON/Tenants.json', 'w' ) as f:
@@ -468,6 +479,10 @@ class ACEye():
             with open('BGP Route Reflectors/JSON/BGP Route Reflectors.json', 'w' ) as f:
                 f.write(parsed_json)
 
+        if "infraPortS" in self.url:
+            with open('Interface Policies/JSON/Interface Policies.json', 'w' ) as f:
+                f.write(parsed_json)
+
     def yaml_file(self, parsed_json):
         clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
         if "Tenant" in self.url:
@@ -586,6 +601,10 @@ class ACEye():
             with open('BGP Route Reflectors/YAML/BGP Route Reflectors.yaml', 'w' ) as f:
                 f.write(clean_yaml)
 
+        if "infraPortS" in self.url:
+            with open('Interface Policies/YAML/Interface Policies.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
     def csv_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -708,6 +727,10 @@ class ACEye():
             with open('BGP Route Reflectors/CSV/BGP Route Reflectors.csv', 'w' ) as f:
                 f.write(csv_output)
 
+        if "infraPortS" in self.url:
+            with open('Interface Policies/CSV/Interface Policies.csv', 'w' ) as f:
+                f.write(csv_output)
+
     def markdown_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -831,6 +854,10 @@ class ACEye():
             with open('BGP Route Reflectors/Markdown/BGP Route Reflectors.md', 'w' ) as f:
                 f.write(markdown_output)
 
+        if "infraPortS" in self.url:
+            with open('Interface Policies/Markdown/Interface Policies.md', 'w' ) as f:
+                f.write(markdown_output)
+
     def html_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -954,6 +981,10 @@ class ACEye():
             with open('BGP Route Reflectors/HTML/BGP Route Reflectors.html', 'w' ) as f:
                 f.write(html_output)
 
+        if "infraPortS" in self.url:
+            with open('Interface Policies/HTML/Interface Policies.html', 'w' ) as f:
+                f.write(html_output)
+
     def mindmap_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -1077,6 +1108,10 @@ class ACEye():
             with open('BGP Route Reflectors/Mindmap/BGP Route Reflectors.md', 'w' ) as f:
                 f.write(mindmap_output)
 
+        if "infraPortS" in self.url:
+            with open('Interface Policies/Mindmap/Interface Policies.md', 'w' ) as f:
+                f.write(mindmap_output)
+
     def all_files(self, parsed_json):
         self.json_file(parsed_json)
         self.yaml_file(parsed_json)
